glue\_genes.glue\_single\_cell.data.DataAnnData
===============================================

.. currentmodule:: glue_genes.glue_single_cell.data

.. autoclass:: DataAnnData

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~DataAnnData.__init__
      ~DataAnnData.add_component
      ~DataAnnData.add_component_link
      ~DataAnnData.add_subset
      ~DataAnnData.broadcast
      ~DataAnnData.component_ids
      ~DataAnnData.compute_fixed_resolution_buffer
      ~DataAnnData.compute_histogram
      ~DataAnnData.compute_statistic
      ~DataAnnData.dtype
      ~DataAnnData.find_component_id
      ~DataAnnData.get_component
      ~DataAnnData.get_data
      ~DataAnnData.get_kind
      ~DataAnnData.get_mask
      ~DataAnnData.get_object
      ~DataAnnData.get_selection_definition
      ~DataAnnData.get_subset_object
      ~DataAnnData.join_on_key
      ~DataAnnData.new_subset
      ~DataAnnData.register_to_hub
      ~DataAnnData.remove_component
      ~DataAnnData.reorder_components
      ~DataAnnData.to_dataframe
      ~DataAnnData.update_components
      ~DataAnnData.update_id
      ~DataAnnData.update_values_from_data
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~DataAnnData.Xdata
      ~DataAnnData.components
      ~DataAnnData.coordinate_components
      ~DataAnnData.coordinate_links
      ~DataAnnData.coords
      ~DataAnnData.data
      ~DataAnnData.derived_components
      ~DataAnnData.derived_links
      ~DataAnnData.externally_derivable_components
      ~DataAnnData.label
      ~DataAnnData.links
      ~DataAnnData.main_components
      ~DataAnnData.ndim
      ~DataAnnData.pixel_aligned_data
      ~DataAnnData.pixel_component_ids
      ~DataAnnData.primary_components
      ~DataAnnData.shape
      ~DataAnnData.size
      ~DataAnnData.subsets
      ~DataAnnData.visible_components
      ~DataAnnData.world_component_ids
   
   